from setuptools import setup

setup(name='ADS_BROWSER_SDK',
      version='0.8',
      description='Sdk for Ads-Browser',
      packages=['ADS_BROWSER_SDK'],
      author='arkptz1',
      author_email='alisbivalka@gmail.com',
      install_requires=['requests'],
      zip_safe=False)